@@ -90,7 +90,7 @@ class MetaObject:
 
         for include in includes:
             _handler = helper.get_class_metadata_object(include)
-            _handler.encode_get_include_obj(os.path.join(src_dir, include), dest_dir, include, tasks, self.version)
+            _handler.encode_get_include_obj(os.path.join(src_dir, include), dest_dir, _handler.get_obj_name(), tasks, self.version)
         return tasks
 
     @classmethod
@@ -103,6 +103,17 @@ class MetaObject:
             if cls.re_meta_data_obj.fullmatch(entry):
                 tasks.append([include, [src_dir, entry[:-5], dest_dir, version]])
 
+    @classmethod
+    def encode_get_include_obj_from_named_folder(cls, src_dir, dest_dir, include, tasks, version):
+        """
+        возвращает список задач на парсинг объектов этого типа
+        """
+        entries = os.listdir(src_dir)
+        for entry in entries:
+            if os.path.isdir(os.path.join(src_dir, entry)):
+                new_src_dir = os.path.join(src_dir, entry)
+                tasks.append([include, [new_src_dir, include, dest_dir, version]])
+
     def encode_version(self):
         return self.header['version']
 
@@ -137,7 +148,8 @@ class MetaObject:
 
     def write_decode_code(self, dest_dir, file_name):
         for code_name in self.code:
-            helper.txt_write(self.code[code_name], dest_dir, f'{file_name}.{code_name}.1c')
+            if self.code[code_name]:
+                helper.txt_write(self.code[code_name], dest_dir, f'{file_name}.{code_name}.1c')
 
     def encode_code(self, src_dir, file_name):
         for code_name in self.ext_code:
