@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 import collections
 import datetime
+import io
 import os
 import zlib
 from struct import pack, unpack, calcsize
@@ -243,14 +244,53 @@ class ContainerReader(object):
             os.remove(temp_name)
 
 
-def extract(filename, folder):
+def extract(filename, dest_dir, deflate=True, recursive=True):
     """
     Распаковка контейнера. Сахар для ContainerReader
 
     :param filename: полное имя файла-контейнера
     :type filename: string
-    :param folder: каталог назначения
-    :type folder: string
+    :param dest_dir: каталог назначения
+    :type dest_dir: string
+    :param deflate: паспаковка
+    :type deflate: boolean
+    :param recursive: рекурсивно достаем все контейнеры
+    :type recursive: boolean
     """
-    with open(filename, 'rb') as f:
-        ContainerReader(f).extract(folder, deflate=True, recursive=True)
+
+    with open(filename, 'rb') as file:
+        ContainerReader(file).extract(dest_dir, deflate, recursive)
+        # from .cv8file import CV8File
+        # from .cv8file16 import CV8File16
+        # if CV8File16.is_v8_file(file):
+        #     CV8File16.parse(file, dest_dir, deflate=True, recursive=True)
+        # if CV8File.is_v8_file(file):
+        #     CV8File.parse(file, dest_dir, deflate=True, recursive=True)
+        # raise Exception('Not v8file')
+
+
+
+
+
+def decompress_and_extract(src_folder, dest_folder, *, pool=None):
+    helper.clear_dir(dest_folder)
+    entries = os.listdir(src_folder)
+
+    for filename in entries:
+        src_path = os.path.join(src_folder, filename)
+        dest_path = os.path.join(dest_folder, filename)
+        with open(src_path, 'rb') as f:
+            # wbits = -15 т.к. у архивированных файлов нет заголовков
+            decompressor = zlib.decompressobj(-15)
+            data = decompressor.decompress(f.read())
+
+        # Каждый файл внутри контейнера может быть контейнером
+        # Для проверки является ли файл контейнером проверим первые 4 бита
+        # Способ проверки ненадежный - нужно придумать что-то другое
+        file_is_container = data[0:4] == b'\xFF\xFF\xFF\x7F'
+
+        if file_is_container:
+            ContainerReader(io.BytesIO(data)).extract(dest_path, recursive=True)
+        else:
+            with open(dest_path, 'wb') as f:
+                f.write(data)
